@@ -7,27 +7,35 @@
 #include "noteeditdialog.h"
 
 #include <Akonadi/CollectionComboBox>
-#include <Akonadi/Notes/NoteUtils>
+#include <Akonadi/NoteUtils>
 
-#include <KPIMTextEdit/RichTextEditor>
-#include <KPIMTextEdit/RichTextEditorWidget>
+#include <TextCustomEditor/RichTextEditor>
+#include <TextCustomEditor/RichTextEditorWidget>
 
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KSharedConfig>
 
+#include <KWindowConfig>
 #include <QDialogButtonBox>
 #include <QLabel>
 #include <QLineEdit>
 #include <QPushButton>
 #include <QVBoxLayout>
+#include <QWindow>
 
 using namespace CalendarSupport;
 
 QAbstractItemModel *NoteEditDialog::_k_noteEditStubModel = nullptr;
 
+namespace
+{
+static const char myNoteEditDialogGroupName[] = "NoteEditDialog";
+}
+
 NoteEditDialog::NoteEditDialog(QWidget *parent)
     : QDialog(parent)
+    , mNoteTitle(new QLineEdit(this))
 {
     setAttribute(Qt::WA_DeleteOnClose);
     setWindowTitle(i18nc("@title:window", "Create Note"));
@@ -55,7 +63,6 @@ NoteEditDialog::NoteEditDialog(QWidget *parent)
     hbox->setContentsMargins(0, 0, 0, 0);
     hbox->setSpacing(2);
 
-    mNoteTitle = new QLineEdit(this);
     mNoteTitle->setClearButtonEnabled(true);
     mNoteTitle->setObjectName(QStringLiteral("notetitle"));
     mNoteTitle->setFocus();
@@ -70,12 +77,12 @@ NoteEditDialog::NoteEditDialog(QWidget *parent)
     mCollectionCombobox->setAccessibleDescription(i18nc("@info", "Calendar where the new note will be stored."));
 #endif
     mCollectionCombobox->setToolTip(i18nc("@info:tooltip", "Calendar where the new note will be stored."));
-    connect(mCollectionCombobox, qOverload<int>(&Akonadi::CollectionComboBox::currentIndexChanged), this, &NoteEditDialog::slotCollectionChanged);
-    connect(mCollectionCombobox, qOverload<int>(&Akonadi::CollectionComboBox::activated), this, &NoteEditDialog::slotCollectionChanged);
+    connect(mCollectionCombobox, &Akonadi::CollectionComboBox::currentIndexChanged, this, &NoteEditDialog::slotCollectionChanged);
+    connect(mCollectionCombobox, &Akonadi::CollectionComboBox::activated, this, &NoteEditDialog::slotCollectionChanged);
 
-    mNoteText = new KPIMTextEdit::RichTextEditorWidget(parent);
+    mNoteText = new TextCustomEditor::RichTextEditorWidget(parent);
     mNoteText->setObjectName(QStringLiteral("notetext"));
-    connect(mNoteText->editor(), &KPIMTextEdit::RichTextEditor::textChanged, this, &NoteEditDialog::slotUpdateButtons);
+    connect(mNoteText->editor(), &TextCustomEditor::RichTextEditor::textChanged, this, &NoteEditDialog::slotUpdateButtons);
 
     // First line
     hbox->addWidget(mNoteTitle);
@@ -97,24 +104,23 @@ NoteEditDialog::NoteEditDialog(QWidget *parent)
 
 NoteEditDialog::~NoteEditDialog()
 {
-    disconnect(mNoteText->editor(), &KPIMTextEdit::RichTextEditor::textChanged, this, &NoteEditDialog::slotUpdateButtons);
+    disconnect(mNoteText->editor(), &TextCustomEditor::RichTextEditor::textChanged, this, &NoteEditDialog::slotUpdateButtons);
     writeConfig();
 }
 
 void NoteEditDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "NoteEditDialog");
-
-    const QSize size = group.readEntry("Size", QSize(500, 300));
-    if (size.isValid()) {
-        resize(size);
-    }
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(500, 300));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myNoteEditDialogGroupName));
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void NoteEditDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "NoteEditDialog");
-    group.writeEntry("Size", size());
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myNoteEditDialogGroupName));
+    KWindowConfig::saveWindowSize(windowHandle(), group);
     group.sync();
 }
 
@@ -187,6 +193,8 @@ KMime::Message::Ptr NoteEditDialog::note() const
     if (mItem.hasPayload<KMime::Message::Ptr>()) {
         return mItem.payload<KMime::Message::Ptr>();
     } else {
-        return KMime::Message::Ptr();
+        return {};
     }
 }
+
+#include "moc_noteeditdialog.cpp"
