@@ -74,22 +74,22 @@ public:
     {
     }
 
-    Q_REQUIRED_RESULT KCalendarCore::Event::Ptr event() const
+    [[nodiscard]] KCalendarCore::Event::Ptr event() const
     {
         return mEvent;
     }
 
-    Q_REQUIRED_RESULT QString label() const override
+    [[nodiscard]] QString label() const override
     {
         return mEvent->summary();
     }
 
-    Q_REQUIRED_RESULT QDateTime start() const
+    [[nodiscard]] QDateTime start() const
     {
         return mStart;
     }
 
-    Q_REQUIRED_RESULT QDateTime end() const
+    [[nodiscard]] QDateTime end() const
     {
         return mEnd;
     }
@@ -1342,7 +1342,7 @@ void CalPrintPluginBase::drawMonth(QPainter &p, QDate dt, QRect box, int maxdays
         }
     }
 
-    QVector<MonthEventStruct> monthentries;
+    QList<MonthEventStruct> monthentries;
 
     for (const KCalendarCore::Event::Ptr &e : std::as_const(events)) {
         if (!e || (mExcludeConfidential && e->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
@@ -1383,7 +1383,7 @@ void CalPrintPluginBase::drawMonth(QPainter &p, QDate dt, QRect box, int maxdays
 
     //  qSort( monthentries.begin(), monthentries.end() );
 
-    QVector<MonthEventStruct>::ConstIterator mit = monthentries.constBegin();
+    QList<MonthEventStruct>::ConstIterator mit = monthentries.constBegin();
     QDateTime endofmonth(end, QTime(0, 0, 0));
     endofmonth = endofmonth.addDays(1);
     for (; mit != monthentries.constEnd(); ++mit) {
